@@ -93,7 +93,12 @@ if [[ ${USE_VENV} = True ]]; then
 else
     MONASCA_API_BIN_DIR=$(get_python_exec_prefix)
 fi
-MONASCA_API_BASE_URI=${MONASCA_API_SERVICE_PROTOCOL}://${MONASCA_API_SERVICE_HOST}:${MONASCA_API_SERVICE_PORT}
+
+if [[ "${MONASCA_API_USE_MOD_WSGI}" == 'True' && "${MONASCA_API_IMPLEMENTATION_LANG}" == "python" ]]; then
+    MONASCA_API_BASE_URI=${MONASCA_API_SERVICE_PROTOCOL}://${MONASCA_API_SERVICE_HOST}/metrics
+else
+    MONASCA_API_BASE_URI=${MONASCA_API_SERVICE_PROTOCOL}://${MONASCA_API_SERVICE_HOST}:${MONASCA_API_SERVICE_PORT}
+fi
 MONASCA_API_URI_V2=${MONASCA_API_BASE_URI}/v2.0
 
 # Files inside this directory will be visible in gates log
@@ -185,7 +190,12 @@ function start_monasca_services {
     fi
     if is_service_enabled monasca-agent; then
         sudo /usr/local/bin/monasca-reconfigure
-        start_service monasca-agent || restart_service monasca-agent
+        if [ -f /etc/systemd/system/monasca-agent.target ]; then
+            start_service monasca-agent.target || restart_service monasca-agent.target
+        fi
+        if [ -f /etc/systemd/system/monasca-agent.service ]; then
+            start_service monasca-agent.service || restart_service monasca-agent.service
+        fi
     fi
 }
 
@@ -208,7 +218,8 @@ function delete_kafka_topics {
 function unstack_monasca {
     stop_service grafana-server || true
 
-    stop_service monasca-agent || true
+    [[ -f /etc/systemd/system/monasca-agent.target ]] && stop_service monasca-agent.target || true
+    [[ -f /etc/systemd/system/monasca-agent.service ]] && stop_service monasca-agent.service || true
 
     stop_service monasca-thresh || true
 
@@ -598,8 +609,8 @@ function install_schema_metric_database_vertica {
 }
 
 function install_schema_metric_database_cassandra {
-    local CASSANDRA_CONNECT_TIMEOUT=30
-    local CASSANDRA_REQUEST_TIMEOUT=60
+    local CASSANDRA_CONNECT_TIMEOUT=300
+    local CASSANDRA_REQUEST_TIMEOUT=300
     sudo cp -f "${MONASCA_API_DIR}"/devstack/files/cassandra/*.cql $MONASCA_SCHEMA_DIR
     /usr/bin/cqlsh ${SERVICE_HOST} -f $MONASCA_SCHEMA_DIR/monasca_schema.cql \
         --connect-timeout="${CASSANDRA_CONNECT_TIMEOUT}" \
@@ -759,9 +770,14 @@ function install_monasca-api {
     git_clone $MONASCA_API_REPO $MONASCA_API_DIR $MONASCA_API_BRANCH
     setup_develop $MONASCA_API_DIR
 
-    pip_install_gr gunicorn
     install_monasca_common
 
+    if [[ "${MONASCA_API_USE_MOD_WSGI}" == 'True' ]]; then
+        pip_install uwsgi
+    else
+        pip_install_gr gunicorn
+    fi
+
     if [[ "${MONASCA_METRICS_DB,,}" == 'influxdb' ]]; then
         pip_install_gr influxdb
     fi
@@ -838,10 +854,8 @@ function configure_monasca_api_python {
         iniset "$MONASCA_API_CONF" keystone_authtoken region_name $REGION_NAME
         iniset "$MONASCA_API_CONF" keystone_authtoken project_name "admin"
         iniset "$MONASCA_API_CONF" keystone_authtoken password $ADMIN_PASSWORD
-        iniset "$MONASCA_API_CONF" keystone_authtoken identity_uri "http://$SERVICE_HOST:35357"
-        iniset "$MONASCA_API_CONF" keystone_authtoken auth_uri "http://$SERVICE_HOST:5000"
 
-        iniset "$MONASCA_API_CONF" security default_authorized_roles "user, domainuser, domainadmin, monasca-user"
+        iniset "$MONASCA_API_CONF" security default_authorized_roles "monasca-user"
         iniset "$MONASCA_API_CONF" security agent_authorized_roles "monasca-agent"
         iniset "$MONASCA_API_CONF" security read_only_authorized_roles "monasca-read-only-user"
         iniset "$MONASCA_API_CONF" security delegate_authorized_roles "admin"
@@ -856,9 +870,20 @@ function configure_monasca_api_python {
         ln -sf $MONASCA_API_PASTE_INI $MON_API_GATE_CONFIGURATION_DIR
         ln -sf $MONASCA_API_LOGGING_CONF $MON_API_GATE_CONFIGURATION_DIR
 
+        if [ "${MONASCA_API_USE_MOD_WSGI}" == 'True' ]; then
+            configure_monasca_api_python_uwsgi
+        fi
+
     fi
 }
 
+function configure_monasca_api_python_uwsgi {
+    rm -rf $MONASCA_API_UWSGI_CONF
+
+    install -m 600 $MONASCA_API_DIR/etc/api-uwsgi.ini $MONASCA_API_UWSGI_CONF
+    write_uwsgi_config "$MONASCA_API_UWSGI_CONF" "$MONASCA_API_BIN_DIR/monasca-api-wsgi" "/metrics"
+}
+
 function start_monasca_api_python {
     if is_service_enabled monasca-api; then
         echo_summary "Starting monasca-api"
@@ -868,10 +893,16 @@ function start_monasca_api_python {
         local gunicorn="$MONASCA_API_BIN_DIR/gunicorn"
 
         restart_service memcached
-        run_process "monasca-api" "$gunicorn --paste $MONASCA_API_PASTE_INI"
+        if [ "${MONASCA_API_USE_MOD_WSGI}" == 'True' ]; then
+            service_uri=$service_protocol://$MONASCA_API_SERVICE_HOST/api/v2.0
+            run_process "monasca-api" "$MONASCA_API_BIN_DIR/uwsgi --ini $MONASCA_API_UWSGI_CONF" ""
+        else
+            service_uri=$service_protocol://$MONASCA_API_SERVICE_HOST:$service_port
+            run_process "monasca-api" "$gunicorn --paste $MONASCA_API_PASTE_INI"
+        fi
 
         echo "Waiting for monasca-api to start..."
-        if ! wait_for_service $SERVICE_TIMEOUT $service_protocol://$SERVICE_HOST:$service_port; then
+        if ! wait_for_service $SERVICE_TIMEOUT $service_uri; then
             die $LINENO "monasca-api did not start"
         fi
     fi
@@ -920,6 +951,14 @@ function clean_monasca_api_python {
         apt_get -y purge libmysqlclient-dev
     fi
 
+    if [ "$MONASCA_API_USE_MOD_WSGI" == "True" ]; then
+        clean_monasca_api_uwsgi
+    fi
+
+}
+
+function clean_monasca_api_uwsgi {
+    sudo rm -rf $MONASCA_API_UWSGI_CONF
 }
 
 function start_monasca_api {
@@ -1161,6 +1200,11 @@ function clean_monasca_agent {
 
     sudo rm -rf /opt/monasca-agent
 
+    [[ -f /etc/systemd/system/monasca-agent.target ]] && sudo rm /etc/systemd/system/monasca-agent.target
+    [[ -f /etc/systemd/system/monasca-collector.service ]] && sudo rm /etc/systemd/system/monasca-collector.service
+    [[ -f /etc/systemd/system/monasca-forwarder.service ]] && sudo rm /etc/systemd/system/monasca-forwarder.service
+    [[ -f /etc/systemd/system/monasca-statsd.service ]] && sudo rm /etc/systemd/system/monasca-statsd.service
+
     apt_get -y purge libxslt1-dev
     apt_get -y purge libxml2-dev
     apt_get -y purge python-yaml
