@@ -18,20 +18,22 @@ from collections import namedtuple
 from datetime import datetime
 from datetime import timedelta
 import itertools
+import six
 import urllib
 
 from cassandra.auth import PlainTextAuthProvider
 from cassandra.cluster import Cluster
 from cassandra.query import FETCH_SIZE_UNSET
 from cassandra.query import SimpleStatement
-
+from monasca_common.rest import utils as rest_utils
 from oslo_config import cfg
 from oslo_log import log
+from oslo_utils import encodeutils
 from oslo_utils import timeutils
 
 from monasca_api.common.repositories import exceptions
 from monasca_api.common.repositories import metrics_repository
-from monasca_common.rest import utils as rest_utils
+
 
 CONF = cfg.CONF
 LOG = log.getLogger(__name__)
@@ -274,6 +276,15 @@ class MetricsRepository(metrics_repository.AbstractMetricsRepository):
             pair = d.split('\t')
             dim_map[pair[0]] = pair[1]
 
+        if row.metric_id is None:
+            LOG.error(
+                'Metric is missing metric_id, using metric_id=None'
+                ' name: {}, dimensions: {}'.format(
+                    row.metric_name, row.dimensions))
+            return {'id': None,
+                    'name': row.metric_name,
+                    'dimensions': dim_map}
+
         metric = {'id': binascii.hexlify(bytearray(row.metric_id)),
                   'name': row.metric_name,
                   'dimensions': dim_map}
@@ -711,7 +722,8 @@ class MetricsRepository(metrics_repository.AbstractMetricsRepository):
                                  end_timestamp, offset_timestamp,
                                  limit=None, fetch_size=FETCH_SIZE_UNSET):
         conditions = [METRIC_ID_EQ]
-        params = [bytearray.fromhex(metric_id)]
+        decode_metric_id = metric_id if six.PY2 else metric_id.decode('utf-8')
+        params = [bytearray.fromhex(decode_metric_id)]
 
         if offset_timestamp:
             conditions.append(OFFSET_TIME_GT)
@@ -814,10 +826,10 @@ class MetricsRepository(metrics_repository.AbstractMetricsRepository):
         """
         st = timestamp.isoformat()
         if '.' in st:
-            st = st[:23] + 'Z'
+            st = st[:23] + u'Z'
         else:
-            st += '.000Z'
-        return st.decode('utf8')
+            st += u'.000Z'
+        return st
 
     def metrics_statistics(self, tenant_id, region, name, dimensions,
                            start_timestamp, end_timestamp, statistics,
@@ -911,7 +923,7 @@ class MetricsRepository(metrics_repository.AbstractMetricsRepository):
             if stats_end_time > end_time:
                 stats_end_time = end_time
 
-            statistic = {u'name': name.decode('utf8'),
+            statistic = {u'name': encodeutils.safe_decode(name, 'utf-8'),
                          u'id': series['id'],
                          u'dimensions': series['dimensions'],
                          u'columns': columns,
