@@ -418,7 +418,7 @@ class MetricsRepository(metrics_repository.AbstractMetricsRepository):
         for name in dim_name_set:
             json_dim_name_list.append({u'dimension_name': name})
 
-        json_dim_name_list = sorted(json_dim_name_list)
+        json_dim_name_list = sorted(json_dim_name_list, key=lambda x: x[u'dimension_name'])
         return json_dim_name_list
 
     def _build_serie_metric_list_to_v0_11_0(self, series_names, tenant_id, region,
@@ -879,16 +879,17 @@ class MetricsRepository(metrics_repository.AbstractMetricsRepository):
             if 'values' in result.raw['series'][0]:
 
                 for point in result.raw['series'][0]['values']:
-                    alarm_point = {u'timestamp': point[0],
-                                   u'alarm_id': point[1],
-                                   u'metrics': rest_utils.from_json(point[2]),
-                                   u'new_state': point[3],
-                                   u'old_state': point[4],
-                                   u'reason': point[5],
-                                   u'reason_data': point[6],
-                                   u'sub_alarms': rest_utils.from_json(point[7]),
+                    point_list = list(point)
+                    alarm_point = {u'timestamp': point_list[0],
+                                   u'alarm_id': point_list[1],
+                                   u'metrics': rest_utils.from_json(point_list[2]),
+                                   u'new_state': point_list[3],
+                                   u'old_state': point_list[4],
+                                   u'reason': point_list[5],
+                                   u'reason_data': point_list[6],
+                                   u'sub_alarms': rest_utils.from_json(point_list[7]),
                                    u'id': str(self._get_millis_from_timestamp(
-                                       timeutils.parse_isotime(point[0])))}
+                                       timeutils.parse_isotime(point_list[0])))}
 
                     # java api formats these during json serialization
                     if alarm_point[u'sub_alarms']:
