@@ -365,72 +365,72 @@ class TestAlarmRepoDB(base.BaseTestCase):
                              'updated_at': datetime.datetime.now()}]
 
         self.default_ams = [{'alarm_id': '1',
-                             'metric_definition_dimensions_id': '11'},
+                             'metric_definition_dimensions_id': b'11'},
                             {'alarm_id': '1',
-                             'metric_definition_dimensions_id': '22'},
+                             'metric_definition_dimensions_id': b'22'},
                             {'alarm_id': '2',
-                             'metric_definition_dimensions_id': '11'},
+                             'metric_definition_dimensions_id': b'11'},
                             {'alarm_id': '3',
-                             'metric_definition_dimensions_id': '22'},
+                             'metric_definition_dimensions_id': b'22'},
                             {'alarm_id': '234111',
-                             'metric_definition_dimensions_id': '31'},
+                             'metric_definition_dimensions_id': b'31'},
                             {'alarm_id': '234111',
-                             'metric_definition_dimensions_id': '32'}]
+                             'metric_definition_dimensions_id': b'32'}]
 
-        self.default_mdes = [{'id': '1',
+        self.default_mdes = [{'id': b'1',
                               'name': 'cpu.idle_perc',
                               'tenant_id': 'bob',
                               'region': 'west'},
-                             {'id': '111',
+                             {'id': b'111',
                               'name': 'cpu.sys_mem',
                               'tenant_id': 'bob',
                               'region': 'west'},
-                             {'id': '112',
+                             {'id': b'112',
                               'name': 'cpu.idle_perc',
                               'tenant_id': 'bob',
                               'region': 'west'}]
 
-        self.default_mdds = [{'id': '11',
-                              'metric_definition_id': '1',
-                              'metric_dimension_set_id': '1'},
-                             {'id': '22',
-                              'metric_definition_id': '1',
-                              'metric_dimension_set_id': '2'},
-                             {'id': '31',
-                              'metric_definition_id': '111',
-                              'metric_dimension_set_id': '21'},
-                             {'id': '32',
-                              'metric_definition_id': '112',
-                              'metric_dimension_set_id': '22'}]
+        self.default_mdds = [{'id': b'11',
+                              'metric_definition_id': b'1',
+                              'metric_dimension_set_id': b'1'},
+                             {'id': b'22',
+                              'metric_definition_id': b'1',
+                              'metric_dimension_set_id': b'2'},
+                             {'id': b'31',
+                              'metric_definition_id': b'111',
+                              'metric_dimension_set_id': b'21'},
+                             {'id': b'32',
+                              'metric_definition_id': b'112',
+                              'metric_dimension_set_id': b'22'}]
 
-        self.default_mds = [{'dimension_set_id': '1',
+        self.default_mds = [{'dimension_set_id': b'1',
                              'name': 'instance_id',
                              'value': '123'},
-                            {'dimension_set_id': '1',
+                            {'dimension_set_id': b'1',
                              'name': 'service',
                              'value': 'monitoring'},
-                            {'dimension_set_id': '2',
+                            {'dimension_set_id': b'2',
                              'name': 'flavor_id',
                              'value': '222'},
-                            {'dimension_set_id': '21',
+                            {'dimension_set_id': b'21',
                              'name': 'service',
                              'value': 'monitoring'},
-                            {'dimension_set_id': '22',
+                            {'dimension_set_id': b'22',
                              'name': 'service',
                              'value': 'monitoring'},
-                            {'dimension_set_id': '21',
+                            {'dimension_set_id': b'21',
                              'name': 'hostname',
                              'value': 'roland'},
-                            {'dimension_set_id': '22',
+                            {'dimension_set_id': b'22',
                              'name': 'hostname',
                              'value': 'roland'},
-                            {'dimension_set_id': '21',
+                            {'dimension_set_id': b'21',
                              'name': 'region',
                              'value': 'colorado'},
-                            {'dimension_set_id': '22',
+                            {'dimension_set_id': b'22',
                              'name': 'region',
                              'value': 'colorado'},
-                            {'dimension_set_id': '22',
+                            {'dimension_set_id': b'22',
                              'name': 'extra',
                              'value': 'vivi'}]
 
