@@ -26,6 +26,7 @@ import testtools.matchers as matchers
 from mock import Mock
 
 import oslo_config.fixture
+from oslo_serialization import jsonutils
 import six
 
 from monasca_api.common.repositories.model import sub_alarm_definition
@@ -125,7 +126,7 @@ class RESTResponseEquals(object):
         if len(actual) != 1:
             return matchers.Mismatch("Response contains <> 1 item: %r" % actual)
 
-        response_data = json.loads(actual[0])
+        response_data = jsonutils.loads(actual[0])
 
         if u"links" in response_data:
             del response_data[u"links"]
@@ -189,10 +190,9 @@ class TestAlarmsStateHistory(AlarmTestBase):
         response = self.simulate_request(
             u'/v2.0/alarms/%s/state-history/' % ALARM_HISTORY[u"alarm_id"],
             headers={
-                'X-Roles': 'admin',
+                'X-Roles': CONF.security.default_authorized_roles[0],
                 'X-Tenant-Id': TENANT_ID,
             })
-
         self.assertEqual(self.srmock.status, falcon.HTTP_200)
         self.assertThat(response, RESTResponseEquals(expected_elements))
 
@@ -241,7 +241,9 @@ class TestAlarmDefinition(AlarmTestBase):
         }
 
         response = self.simulate_request("/v2.0/alarm-definitions/",
-                                         headers={'X-Roles': 'admin', 'X-Tenant-Id': TENANT_ID},
+                                         headers={'X-Roles':
+                                                  CONF.security.default_authorized_roles[0],
+                                                  'X-Tenant-Id': TENANT_ID},
                                          method="POST",
                                          body=json.dumps(alarm_def))
 
@@ -254,24 +256,24 @@ class TestAlarmDefinition(AlarmTestBase):
         return_value.create_alarm_definition.return_value = u"00000001-0001-0001-0001-000000000001"
 
         valid_expressions = [
-            "max(-_.千幸福的笑脸{घोड़ा=馬,  "
-            "dn2=dv2,千幸福的笑脸घ=千幸福的笑脸घ}) gte 100 "
-            "times 3 && "
-            "(min(ເຮືອນ{dn3=dv3,家=дом}) < 10 or sum(biz{dn5=dv5}) >99 and "
-            "count(fizzle) lt 0or count(baz) > 1)".decode('utf8'),
+            u"max(-_.千幸福的笑脸{घोड़ा=馬,  "
+            u"dn2=dv2,千幸福的笑脸घ=千幸福的笑脸घ}) gte 100 "
+            u"times 3 && "
+            u"(min(ເຮືອນ{dn3=dv3,家=дом}) < 10 or sum(biz{dn5=dv5}) >99 and "
+            u"count(fizzle) lt 0or count(baz) > 1)",
 
-            "max(foo{hostname=mini-mon,千=千}, 120) > 100 and (max(bar)>100 "
-            " or max(biz)>100)".decode('utf8'),
+            u"max(foo{hostname=mini-mon,千=千}, 120) > 100 and (max(bar)>100 "
+            u" or max(biz)>100)",
 
-            "max(foo)>=100",
+            u"max(foo)>=100",
 
-            "test_metric{this=that, that =  this} < 1",
+            u"test_metric{this=that, that =  this} < 1",
 
-            "max  (  3test_metric5  {  this  =  that  })  lt  5 times    3",
+            u"max  (  3test_metric5  {  this  =  that  })  lt  5 times    3",
 
-            "3test_metric5 lt 3",
+            u"3test_metric5 lt 3",
 
-            "ntp.offset > 1 or ntp.offset < -5",
+            u"ntp.offset > 1 or ntp.offset < -5",
         ]
 
         alarm_def = {
@@ -297,7 +299,9 @@ class TestAlarmDefinition(AlarmTestBase):
             alarm_def[u'expression'] = expression
             expected_data[u'expression'] = expression
             response = self.simulate_request("/v2.0/alarm-definitions/",
-                                             headers={'X-Roles': 'admin', 'X-Tenant-Id': TENANT_ID},
+                                             headers={'X-Roles':
+                                                      CONF.security.default_authorized_roles[0],
+                                                      'X-Tenant-Id': TENANT_ID},
                                              method="POST",
                                              body=json.dumps(alarm_def))
 
@@ -321,7 +325,8 @@ class TestAlarmDefinition(AlarmTestBase):
         for expression in bad_expressions:
             alarm_def[u'expression'] = expression
             self.simulate_request("/v2.0/alarm-definitions/",
-                                  headers={'X-Roles': 'admin', 'X-Tenant-Id': TENANT_ID},
+                                  headers={'X-Roles': CONF.security.default_authorized_roles[0],
+                                           'X-Tenant-Id': TENANT_ID},
                                   method="POST",
                                   body=json.dumps(alarm_def))
 
@@ -400,12 +405,14 @@ class TestAlarmDefinition(AlarmTestBase):
         }
 
         result = self.simulate_request("/v2.0/alarm-definitions/%s" % expected_def[u'id'],
-                                       headers={'X-Roles': 'admin', 'X-Tenant-Id': TENANT_ID},
+                                       headers={'X-Roles':
+                                                CONF.security.default_authorized_roles[0],
+                                                'X-Tenant-Id': TENANT_ID},
                                        method="PUT",
                                        body=json.dumps(alarm_def))
 
         self.assertEqual(self.srmock.status, falcon.HTTP_200)
-        result_def = json.loads(result[0])
+        result_def = jsonutils.loads(result[0])
         self.assertEqual(result_def, expected_def)
 
     def test_alarm_definition_patch_no_id(self):
@@ -416,7 +423,7 @@ class TestAlarmDefinition(AlarmTestBase):
         self.simulate_request(
             "/v2.0/alarm-definitions/",
             headers={
-                'X-Roles': 'admin',
+                'X-Roles': CONF.security.default_authorized_roles[0],
                 'X-Tenant-Id': TENANT_ID},
             method="PATCH",
             body=json.dumps(alarm_def))
@@ -431,7 +438,7 @@ class TestAlarmDefinition(AlarmTestBase):
         self.simulate_request(
             "/v2.0/alarm-definitions/",
             headers={
-                'X-Roles': 'admin',
+                'X-Roles': CONF.security.default_authorized_roles[0],
                 'X-Tenant-Id': TENANT_ID},
             method="PUT",
             body=json.dumps(alarm_def))
@@ -443,7 +450,7 @@ class TestAlarmDefinition(AlarmTestBase):
         self.simulate_request(
             "/v2.0/alarm-definitions/",
             headers={
-                'X-Roles': 'admin',
+                'X-Roles': CONF.security.default_authorized_roles[0],
                 'X-Tenant-Id': TENANT_ID},
             method="DELETE")
 
@@ -519,12 +526,14 @@ class TestAlarmDefinition(AlarmTestBase):
         }
 
         result = self.simulate_request("/v2.0/alarm-definitions/%s" % expected_def[u'id'],
-                                       headers={'X-Roles': 'admin', 'X-Tenant-Id': TENANT_ID},
+                                       headers={'X-Roles':
+                                                CONF.security.default_authorized_roles[0],
+                                                'X-Tenant-Id': TENANT_ID},
                                        method="PATCH",
                                        body=json.dumps(alarm_def))
 
         self.assertEqual(self.srmock.status, falcon.HTTP_200)
-        result_def = json.loads(result[0])
+        result_def = jsonutils.loads(result[0])
         self.assertEqual(result_def, expected_def)
         # If the alarm-definition-updated event does not have all of the
         # fields set, the Threshold Engine will get confused. For example,
@@ -629,19 +638,23 @@ class TestAlarmDefinition(AlarmTestBase):
         }
 
         result = self.simulate_request("/v2.0/alarm-definitions/%s" % expected_def[u'id'],
-                                       headers={'X-Roles': 'admin', 'X-Tenant-Id': TENANT_ID},
+                                       headers={'X-Roles':
+                                                CONF.security.default_authorized_roles[0],
+                                                'X-Tenant-Id': TENANT_ID},
                                        method="PUT",
                                        body=json.dumps(alarm_def))
 
         self.assertEqual(self.srmock.status, falcon.HTTP_200)
-        result_def = json.loads(result[0])
+        result_def = jsonutils.loads(result[0])
         self.assertEqual(result_def, expected_def)
 
         for key, value in alarm_def.items():
             del alarm_def[key]
 
             self.simulate_request("/v2.0/alarm-definitions/%s" % expected_def[u'id'],
-                                  headers={'X-Roles': 'admin', 'X-Tenant-Id': TENANT_ID},
+                                  headers={'X-Roles':
+                                           CONF.security.default_authorized_roles[0],
+                                           'X-Tenant-Id': TENANT_ID},
                                   method="PUT",
                                   body=json.dumps(alarm_def))
             self.assertEqual(self.srmock.status, "422 Unprocessable Entity",
@@ -683,7 +696,7 @@ class TestAlarmDefinition(AlarmTestBase):
         response = self.simulate_request(
             '/v2.0/alarm-definitions/%s' % (expected_data[u'id']),
             headers={
-                'X-Roles': 'admin',
+                'X-Roles': CONF.security.default_authorized_roles[0],
                 'X-Tenant-Id': TENANT_ID,
             })
 
@@ -722,7 +735,7 @@ class TestAlarmDefinition(AlarmTestBase):
         response = self.simulate_request(
             '/v2.0/alarm-definitions/%s' % (expected_data[u'id']),
             headers={
-                'X-Roles': 'admin',
+                'X-Roles': CONF.security.default_authorized_roles[0],
                 'X-Tenant-Id': TENANT_ID,
             })
 
@@ -760,7 +773,7 @@ class TestAlarmDefinition(AlarmTestBase):
         response = self.simulate_request(
             '/v2.0/alarm-definitions/%s' % (expected_data[u'id']),
             headers={
-                'X-Roles': 'admin',
+                'X-Roles': CONF.security.default_authorized_roles[0],
                 'X-Tenant-Id': TENANT_ID,
             }
         )
