@@ -216,8 +216,9 @@ class TestRepoMetricsInfluxDB(base.BaseTestCase):
 
         mock_client.query.assert_called_once_with(
             'show tag values from "custom_metric" with key = "hostname"'
-            ' where _tenant_id = \'38dc2a2549f94d2e9a4fa1cc45a4970c\''
-            '  and _region = \'useast\' ')
+            ' where _tenant_id = \'{tenant}\''
+            '  and _region = \'{region}\' '.format(tenant=b'38dc2a2549f94d2e9a4fa1cc45a4970c',
+                                                   region=b'useast'))
 
     @patch("monasca_api.common.repositories.influxdb."
            "metrics_repository.client.InfluxDBClient")
@@ -325,7 +326,52 @@ class TestRepoMetricsCassandra(base.BaseTestCase):
             limit=1)
 
         self.assertEqual([{
-            u'id': u'01d39f19798ed27bbf458300bf843edd17654614',
+            u'id': b'01d39f19798ed27bbf458300bf843edd17654614',
+            u'name': u'disk.space_used_perc',
+            u'dimensions': {
+                u'device': u'rootfs',
+                u'hostname': u'host0',
+                u'mount_point': u'/',
+                u'hosttype': u'native'
+            }}], result)
+
+    # As Cassandra allows sparse data, it is possible to have a missing metric_id
+    @patch("monasca_api.common.repositories.cassandra."
+           "metrics_repository.Cluster.connect")
+    def test_list_metrics_empty_metric_id(self, cassandra_connect_mock):
+        cassandra_session_mock = cassandra_connect_mock.return_value
+        cassandra_future_mock = cassandra_session_mock.execute_async.return_value
+
+        Metric = namedtuple('Metric', 'metric_id metric_name dimensions')
+
+        cassandra_future_mock.result.return_value = [
+            Metric(
+                metric_id=None,
+                metric_name='disk.space_used_perc',
+                dimensions=[
+                    'device\trootfs',
+                    'hostname\thost0',
+                    'hosttype\tnative',
+                    'mount_point\t/']
+            )
+        ]
+
+        repo = cassandra_repo.MetricsRepository()
+
+        result = repo.list_metrics(
+            "0b5e7d8c43f74430add94fba09ffd66e",
+            "region",
+            name="disk.space_user_perc",
+            dimensions={
+                "hostname": "host0",
+                "hosttype": "native",
+                "mount_point": "/",
+                "device": "rootfs"},
+            offset=None,
+            limit=1)
+
+        self.assertEqual([{
+            u'id': None,
             u'name': u'disk.space_used_perc',
             u'dimensions': {
                 u'device': u'rootfs',
@@ -492,7 +538,7 @@ class TestRepoMetricsCassandra(base.BaseTestCase):
                 u'statistics': [[u'2016-05-19T11:58:24.000Z', 95.5, 94.0, 97.0, 4, 382.0]],
                 u'name': u'cpu.idle_perc',
                 u'columns': [u'timestamp', 'avg', 'min', 'max', 'count', 'sum'],
-                u'id': '01d39f19798ed27bbf458300bf843edd17654614'
+                u'id': b'01d39f19798ed27bbf458300bf843edd17654614'
             }
         ], result)
 
@@ -540,7 +586,7 @@ class TestRepoMetricsCassandra(base.BaseTestCase):
                 u'statistics': [[u'2016-05-19T11:58:24.000Z', 95.5, 94.0, 97.0, 4, 382.0]],
                 u'name': u'cpu.idle_perc',
                 u'columns': [u'timestamp', 'avg', 'min', 'max', 'count', 'sum'],
-                u'id': '01d39f19798ed27bbf458300bf843edd17654614'
+                u'id': b'01d39f19798ed27bbf458300bf843edd17654614'
             }
         ], result)
 
